/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import { LexicalComposer } from '@lexical/react/LexicalComposer';
import * as React from 'react';

import { SharedHistoryContext } from './context/SharedHistoryContext';
import Editor from './Editor';
import PlaygroundNodes from './nodes/PlaygroundNodes';
import PlaygroundEditorTheme from './themes/PlaygroundEditorTheme';
import './EditorComposer.css';
import ToolbarPlugin from './plugins/ToolbarPlugin/ToolbarPlugin';
import InsertDropdown from './plugins/ToolbarPlugin/components/InsertDropdown';

function App(): JSX.Element {
  const initialConfig = {
    namespace: 'PlaygroundEditor',
    nodes: [...PlaygroundNodes],
    onError: (error) => {
      throw error;
    },
    theme: PlaygroundEditorTheme,
  };

  return (
    <LexicalComposer initialConfig={initialConfig}>
      {/* <SharedHistoryContext> */}
      <div className="editor-shell">
        <Editor hashtagsEnabled={true}>
          <ToolbarPlugin></ToolbarPlugin>
        </Editor>
      </div>
      {/* </SharedHistoryContext> */}
    </LexicalComposer>
  );
}

export default function PlaygroundApp(): JSX.Element {
  return <App />;
}
